@@ -20,10 +20,11 @@ class Resource:
             setattr(self, key, json[key])
 
     def __repr__(self):
-        name = getattr(self, "name", getattr(self, "title", None))
-        if name is not None:
-            return "<{}: {}>".format(self.__class__.__name__, str(name))
-        return super().__repr__()
+        name = getattr(self, "name", None)
+        title = getattr(self, "title", None)
+        id_ = getattr(self, "id", None)
+        repr_ = str(name or title or id_)
+        return "<{}: {}>".format(self.__class__.__name__, repr_)
 
     def asdict(self):
         """
@@ -70,16 +71,6 @@ class Resource:
                 break
             index += len(items)
 
-    def get_artist(self):
-        """
-        :returns: the :mod:`Artist <deezer.resources.Artist>` of the resource
-        :raises TypeError: if the object is not album or track
-        """
-        # pylint: disable=E1101
-        if not isinstance(self, (Album, Track)):
-            raise TypeError("Is neither an Album or a Track")
-        return self.client.get_artist(self.artist.id)
-
 
 class Album(Resource):
     """
@@ -88,6 +79,14 @@ class Album(Resource):
     All the fields documented on Deezer are accessible by as class attributes.
     """
 
+    def get_artist(self):
+        """
+        Get the artist of the Album.
+
+        :returns: the :mod:`Artist <deezer.resources.Artist>` of the Album
+        """
+        return self.client.get_artist(self.artist.id)
+
     def get_tracks(self, **kwargs):
         """
         Get a list of album's tracks.
@@ -206,6 +205,14 @@ class Track(Resource):
     All the fields documented on Deezer are accessible by as class attributes.
     """
 
+    def get_artist(self):
+        """
+        Get the artist of the Track.
+
+        :returns: the :mod:`Artist <deezer.resources.Artist>` of the Album
+        """
+        return self.client.get_artist(self.artist.id)
+
     def get_album(self):
         """
         :returns: the :mod:`Album <deezer.resources.Album>` instance
@@ -423,3 +430,35 @@ class Chart(Resource):
         :returns: list of :mod:`Playlist <deezer.resources.Playlist>` instances
         """
         return self.iter_relation("playlists", **kwargs)
+
+
+class Podcast(Resource):
+    """
+    To access an :deezer-api:`podcast object <podcast>`.
+
+    All the fields documented on Deezer are accessible by as class attributes.
+    """
+
+    def get_episodes(self, **kwargs):
+        """
+        Get episodes from a podcast
+
+        :returns: list of :mod:`Episode <deezer.resources.Episode>` instances
+        """
+        return self.get_relation("episodes", **kwargs)
+
+    def iter_episodes(self, **kwargs):
+        """
+        Iterate over episodes of a podcast
+
+        :returns: list of :mod:`Episode <deezer.resources.Episode>` instances
+        """
+        return self.iter_relation("episodes", **kwargs)
+
+
+class Episode(Resource):
+    """
+    To access an :deezer-api:`episode object <episode>`.
+
+    All the fields documented on Deezer are accessible by as class attributes.
+    """
